==> webpdf-wsclient-2.0.2-sources.jar: net/webpdf/wsclient/schema/operation/WatermarkTextType.java <==

package net.webpdf.wsclient.schema.operation;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for WatermarkTextType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="WatermarkTextType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;all&gt;
 *         &lt;element name="font" type="{http://schema.webpdf.de/1.0/operation}WatermarkFontType" minOccurs="0"/&gt;
 *         &lt;element name="position" type="{http://schema.webpdf.de/1.0/operation}WatermarkPositionType" minOccurs="0"/&gt;
 *       &lt;/all&gt;
 *       &lt;attribute name="text" type="{http://www.w3.org/2001/XMLSchema}string" default="Confidential" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "WatermarkTextType", propOrder = {

})
public class WatermarkTextType {

    protected WatermarkFontType font;
    protected WatermarkPositionType position;
    @XmlAttribute(name = "text")
    protected String text;

    /**
     * Gets the value of the font property.
     * 
     * @return
     *     possible object is
     *     {@link WatermarkFontType }
     *     
     */
    public WatermarkFontType getFont() {
        return font;
    }

    /**
     * Sets the value of the font property.
     * 
     * @param value
     *     allowed object is
     *     {@link WatermarkFontType }
     *     
     */
    public void setFont(WatermarkFontType value) {
        this.font = value;
    }

    public boolean isSetFont() {
        return (this.font!= null);
    }

    /**
     * Gets the value of the position property.
     * 
     * @return
     *     possible object is
     *     {@link WatermarkPositionType }
     *     
     */
    public WatermarkPositionType getPosition() {
        return position;
    }

    /**
     * Sets the value of the position property.
     * 
     * @param value
     *     allowed object is
     *     {@link WatermarkPositionType }
     *     
     */
    public void setPosition(WatermarkPositionType value) {
        this.position = value;
    }

    public boolean isSetPosition() {
        return (this.position!= null);
    }

    /**
     * Gets the value of the text property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getText() {
        if (text == null) {
            return "Confidential";
        } else {
            return text;
        }
    }

    /**
     * Sets the value of the text property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setText(String value) {
        this.text = value;
    }

    public boolean isSetText() {
        return (this.text!= null);
    }

}

==> webpdf-wsclient-9.0.0-sources.jar: net/webpdf/wsclient/schema/operation/WatermarkTextType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p349049_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:p505059_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Used to add a text watermark.&lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for WatermarkTextType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="WatermarkTextType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <all>
 *         <element name="font" type="{http://schema.webpdf.de/1.0/operation}WatermarkFontType" minOccurs="0"/>
 *         <element name="position" type="{http://schema.webpdf.de/1.0/operation}WatermarkPositionType" minOccurs="0"/>
 *       </all>
 *       <attribute name="text" type="{http://www.w3.org/2001/XMLSchema}string" default="Confidential" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "WatermarkTextType", propOrder = {

})
public class WatermarkTextType {

    protected WatermarkFontType font;
    protected WatermarkPositionType position;
    @XmlAttribute(name = "text")
    protected String text;

    /**
     * Gets the value of the font property.
     * 
     * @return
     *     possible object is
     *     {@link WatermarkFontType }
     *     
     */
    public WatermarkFontType getFont() {
        return font;
    }

    /**
     * Sets the value of the font property.
     * 
     * @param value
     *     allowed object is
     *     {@link WatermarkFontType }
     *     
     */
    public void setFont(WatermarkFontType value) {
        this.font = value;
    }

    public boolean isSetFont() {
        return (this.font!= null);
    }

    /**
     * Gets the value of the position property.
     * 
     * @return
     *     possible object is
     *     {@link WatermarkPositionType }
     *     
     */
    public WatermarkPositionType getPosition() {
        return position;
    }

    /**
     * Sets the value of the position property.
     * 
     * @param value
     *     allowed object is
     *     {@link WatermarkPositionType }
     *     
     */
    public void setPosition(WatermarkPositionType value) {
        this.position = value;
    }

    public boolean isSetPosition() {
        return (this.position!= null);
    }

    /**
     * Gets the value of the text property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getText() {
        if (text == null) {
            return "Confidential";
        } else {
            return text;
        }
    }

    /**
     * Sets the value of the text property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setText(String value) {
        this.text = value;
    }

    public boolean isSetText() {
        return (this.text!= null);
    }

}
